from flask import Flask, render_template
import re
import docker
import requests

app = Flask(__name__)

TRAEFIK_API_URL = "https://norman.lan/api/http/routers"
REGEX_PATTERNS = [r".*\.gederico\.dynu\.net"]

client = docker.from_env()
containers = client.containers.list(all=True)  # Get all containers

def get_routers():
    response = requests.get(TRAEFIK_API_URL, verify=False)  # Ignore SSL certificate verification
    if response.status_code == 200:
        routers = response.json()
        filtered_routers = filter_routers(routers)
        return filtered_routers
    return []

def filter_routers(routers):
    filtered_routers = []
    for router in routers:
        for pattern in REGEX_PATTERNS:
            if re.match(pattern, router['rule'].split('`')[1]):
                router['description'] = get_router_description(router['name'])
                filtered_routers.append(router)
                break
    return filtered_routers

def get_router_description(router_name):
    try:
        service_name = router_name.split('@')[0]
        for container in containers:
            labels = container.attrs.get('Config', {}).get('Labels', {})
            description = labels.get('traefik-frontend.http.routers.' + service_name + '.description')
            if description:
                return description
    except Exception as e:
        print(f"Error fetching description for {router_name}: {e}")
    return 'No description available'

def truncate_and_uppercase_name(name):
    return name.split('@')[0].upper()

@app.route('/')
def index():
    routers = get_routers()
    for router in routers:
        router['truncated_name'] = truncate_and_uppercase_name(router['name'])
    return render_template('index.html', routers=routers)

if __name__ == '__main__':
    app.run(host='0.0.0.0', debug=True)

